.. _usage-images:


Pictures
=================
The :doc:`dhlab.images <generated/images>` subpackage contains functionality for processing pictures
in `NB Digital`_.

Use
-------
Import functions and classes from :doc:`generated/images.nbpictures` like this:


.. code-block::

   from dhlab.images.nbpictures import ...


-------------------------------------

.. _NB Digital: https://www.nb.no/search
